python-opentree
===============

This package is a python library designed to make it easier to work with web services and
data resources associated with the [Open Tree of Life](https://opentreeoflife.github.io)
project.


Prior work / design / road map
==============================

This package will use supersede [peyotl](http://opentreeoflife.github.io/peyotl/) at
    some point.

The initial goal is provide client-side interface to Open Tree for an Open Tree workshop
at the [2020 SSB Meeting](https://systbiol.github.io/ssb2020/) in Gainesville, FL.

 
